@@ -1,9 +1,10 @@
-from typing import Any, Dict, Optional, Tuple, TypeVar, Union, cast
+from typing import Any, Dict, Literal, Optional, Tuple, TypeVar, Union, cast
 import httpx
 import logging
 import warnings
 import urllib3
 import json
+from urllib.parse import quote
 from secrets import token_bytes, token_hex
 from base64 import b64decode, b64encode
 
@@ -12,7 +13,7 @@ from cryptography.hazmat.primitives.padding import PKCS7
 from cryptography.hazmat.primitives.hashes import SHA256
 from cryptography.hazmat.primitives.hmac import HMAC
 
-from .typing import ActivitesTVType, ActivitiesChannelType, ApplicationIntentType, ApplicationsType, ChannelDbTv, ChannelListType, ChannelType, ChannelsCurrentType, ChannelsType, ContextType, SystemType
+from .typing import ActivitesTVType, ActivitiesChannelType, ApplicationIntentType, ApplicationsType, ChannelDbTv, ChannelListType, ChannelType, ChannelsCurrentType, ChannelsType, ContextType, FavoriteType, SystemType
 
 LOG = logging.getLogger(__name__)
 TIMEOUT = 5.0
@@ -106,6 +107,7 @@ class PhilipsTV(object):
         self.audio_volume = None
         self.channels: Optional[ChannelsType] = None
         self.channel: Optional[Union[ActivitesTVType, ChannelsCurrentType]] = None
+        self.channel_db_tv: Optional[ChannelDbTv] = None
         self.applications: Optional[ApplicationsType] = None
         self.application: Optional[ApplicationIntentType] = None
         self.context: Optional[ContextType] = None
@@ -115,6 +117,7 @@ class PhilipsTV(object):
         self.ambilight_cached = None
         self.ambilight_measured = None
         self.ambilight_processed = None
+        self.powerstate = None
         if auth_shared_key:
             self.auth_shared_key = auth_shared_key
         else:
@@ -393,6 +396,7 @@ class PhilipsTV(object):
                 await self.getSystem()
                 await self.setTransport(self.secured_transport)
                 await self.getSources()
+                await self.getChannelLists()
                 await self.getChannels()
                 await self.getApplications()
 
@@ -440,9 +444,9 @@ class PhilipsTV(object):
     async def getChannels(self):
         if self.api_version >= 5:
             self.channels = {}
-            for channelListId in await self.getChannelLists():
+            for channelList in self.channel_db_tv.get("channelLists"):
                 r = cast(Optional[ChannelListType], await self._getReq(
-                    'channeldb/tv/channelLists/{}'.format(channelListId)
+                    'channeldb/tv/channelLists/{}'.format(channelList["id"])
                 ))
                 if r:
                     for channel in r.get('Channel', []):
@@ -483,10 +487,10 @@ class PhilipsTV(object):
             self.context = r
             return r
 
-    async def setChannel(self, ccid):
+    async def setChannel(self, ccid, list_id: str = "alltv"):
         channel: Union[ActivitesTVType, ChannelsCurrentType]
         if self.api_version >= 5:
-            channel = {"channelList": {"id": "alltv"}, "channel": {"ccid": ccid}}
+            channel = {"channelList": {"id": list_id}, "channel": {"ccid": ccid}}
             if await self._postReq('activities/tv', cast(Dict, channel)) is not None:
                 self.channel = channel
         else:
@@ -498,15 +502,47 @@ class PhilipsTV(object):
         if self.api_version >= 5:
             r = cast(ChannelDbTv, await self._getReq('channeldb/tv'))
             if r:
-                # could be alltv and allsat
-                return [l['id'] for l in r.get('channelLists', [])]
+                self.channel_db_tv = r
             else:
-                return []
+                self.channel_db_tv = None
         else:
-            return []
+            self.channel_db_tv = {
+                "channelLists": [
+                    {"id": "alltv"}
+                ],
+                "favoriteLists": []
+            }
+        return self.channel_db_tv
+
+    async def getChannelList(self, list_type: str, list_id: str):
+        if self.api_version >= 5:
+            return cast(Optional[ChannelListType], await self._getReq(
+                f"channeldb/tv/{list_type}/{list_id}"
+            ))
+        else:
+            if list_type == "channelLists" and list_id == "all":
+                return cast(Optional[ChannelsType], await self._getReq('channels'))
+            return None
 
     async def getSources(self):
-        if self.api_version < 5:
+        if self.api_version == 6:
+            self.sources = {
+                "com.mediatek.tvinput/.hdmi.HDMIInputService/HW5" : {
+                    "name": "HDMI 1"
+                },
+                "com.mediatek.tvinput/.hdmi.HDMIInputService/HW6" : {
+                    "name": "HDMI 2"
+                },
+                "com.mediatek.tvinput/.hdmi.HDMIInputService/HW7" : {
+                    "name": "HDMI 3"
+                },
+                "com.mediatek.tvinput/.hdmi.HDMIInputService/HW8" : {
+                    "name": "HDMI 4"
+                },
+            }
+            return self.sources
+
+        if self.api_version == 1:
             r = await self._getReq('sources')
             if r:
                 self.sources = r
@@ -526,14 +562,27 @@ class PhilipsTV(object):
     async def getSourceName(self, srcid) -> Optional[str]:
         if not self.sources:
             return None
-        if self.api_version < 5:
-            return self.sources.get(srcid, dict()).get('name', None)
-        return None
+        return self.sources.get(srcid, dict()).get('name', None)
 
     async def setSource(self, source_id):
-        if self.api_version < 5:
-            if await self._postReq('sources/current', {'id': source_id}) is not None:
+        if self.api_version == 1:
+            r = await self._postReq('sources/current', {'id': source_id}) 
+            if r is not None:
                 self.source_id = source_id
+                return True
+            return False
+
+        if self.api_version == 6:
+            data = quote(source_id, safe='')
+            intent: ApplicationIntentType = {
+                "extras": {"uri": f"content://android.media.tv/passthrough/{data}"},
+                "action": "org.droidtv.playtv.SELECTURI", 
+                "component": {
+                    "packageName":"org.droidtv.playtv",
+                    "className":"org.droidtv.playtv.PlayTvActivity"
+                }
+            }
+            return await self.setApplication(intent)
 
     async def getApplications(self):
         if self.api_version >= 5:
@@ -601,7 +650,7 @@ class PhilipsTV(object):
                 self.screenstate = state
                 return True
         return False
-
+    
     async def setApplication(self, intent: ApplicationIntentType):
         if self.api_version >= 5:
             data = {
